]> git.sesse.net Git - nageru/blobdiff - theme.h
Reduce a little console spam.
[nageru] / theme.h
diff --git a/theme.h b/theme.h
index b04050e51d05a6331b21d65409adda3311a61fa0..cc8765c8e5e055d6e77eb9eced8da43b8e3e44e7 100644 (file)
--- a/theme.h
+++ b/theme.h
@@ -103,7 +103,7 @@ private:
 // the mixer, and communicates that state over to the actual YCbCrInput.
 class LiveInputWrapper {
 public:
// Note: <override_bounce> is irrelevant for PixelFormat_8BitRGBA.
        LiveInputWrapper(Theme *theme, movit::EffectChain *chain, bmusb::PixelFormat pixel_format, bool override_bounce, bool deinterlace);
 
        void connect_signal(int signal_num);
@@ -112,7 +112,7 @@ public:
        {
                if (deinterlace) {
                        return deinterlace_effect;
-               } else if (pixel_format == bmusb::PixelFormat_8BitRGBA) {
+               } else if (pixel_format == bmusb::PixelFormat_8BitBGRA) {
                        return rgba_inputs[0];
                } else {
                        return ycbcr_inputs[0];
@@ -122,6 +122,7 @@ public:
 private:
        Theme *theme;  // Not owned by us.
        bmusb::PixelFormat pixel_format;
+       movit::YCbCrFormat input_ycbcr_format;
        std::vector<movit::YCbCrInput *> ycbcr_inputs;  // Multiple ones if deinterlacing. Owned by the chain.
        std::vector<movit::FlatInput *> rgba_inputs;  // Multiple ones if deinterlacing. Owned by the chain.
        movit::Effect *deinterlace_effect = nullptr;  // Owned by the chain.
@@ -103,7 +103,7 @@ private:
 class LiveInputWrapper {
 public:
-       // Note: <override_bounce> is irrelevant for PixelFormat_8BitRGBA.
+       // Note: <override_bounce> is irrelevant for PixelFormat_8BitBGRA.
        LiveInputWrapper(Theme *theme, movit::EffectChain *chain, bmusb::PixelFormat pixel_format, bool override_bounce, bool deinterlace);
 